-- Moficicacion de tabla de configuración
ALTER TABLE cat_configuracion
   ADD COLUMN `copias_venta` INT DEFAULT '1' NULL AFTER `desglosa_total`;

   
ALTER TABLE `cat_productos_servicios` 
   ADD COLUMN `codigo_proveedor` VARCHAR(20)  NULL AFTER `clave`;



DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_configuracion`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_configuracion`()
    SQL SECURITY INVOKER
    COMMENT 'Obtiene la información de configuración'
BEGIN
	SELECT cfg.id_sucursal,
		cfg.default_image,
		cfg.group_len,
		cfg.desglosa_total,
		cfg.cashdrawer_unc,
		cfg.url_existencias,
		cfg.url_sync_empresa,
		cfg.url_sync_sucursales,
		cfg.url_sync_productos,
		cfg.url_sync_precios,
		cfg.url_sync_usuarios,
		cfg.url_sync_ventas,
		cfg.token,
		COALESCE(cfg.logo, '') AS logo,
		cfg.print_hoffset,
		cfg.copias_venta
	FROM cat_configuracion AS cfg;
END$$

DELIMITER ;



DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_updateConfig`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_updateConfig`(
	in_desglosa_total INT,
	in_cashdrawer_unc TEXT,
	in_token VARCHAR(20),
	in_sucursal INT,
	in_offset INT,
	in_copiasventa INT
)
    COMMENT 'Guarda las opciones de configuración general'
BEGIN
	UPDATE cat_configuracion
	SET desglosa_total = in_desglosa_total,
		cashdrawer_unc = in_cashdrawer_unc,
		token = in_token,
		id_sucursal = in_sucursal,
		print_hoffset = in_offset,
		copias_venta = in_copiasventa;
END$$

DELIMITER ;



DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_producto_x_codigo`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_producto_x_codigo`(
	p_codigo VARCHAR(30)
)
    COMMENT 'Búsqueda de Producto por Código'
BEGIN
	SELECT 1 AS cantidad,
		prd.modelo,
		prd.nombre AS descripcion,
		prd.precio_venta AS precio_unitario,
		prd.precio_venta,
		0.00 AS subtotal,
		0.00 AS iva,
		0.00 AS total,
		prd.tasa_iva,
		prd.iva_incluido,
		prd.imagen,
		prd.id_producto,
		prd.clave
	FROM cat_productos_servicios AS prd
	JOIN cat_configuracion AS cfg
	WHERE BINARY prd.clave = p_codigo
	        OR prd.codigo_proveedor = p_codigo
		OR BINARY LEFT(prd.clave, cfg.group_len) = p_codigo
		OR BINARY prd.modelo = p_codigo;
END$$

DELIMITER ;



DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_buscarProducto`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_buscarProducto`(
	in_info TEXT
)
    COMMENT 'Busca un producto por descripción, nombre, modelo o clave'
BEGIN
	SET in_info = CONCAT('%', in_info, '%');
	
	SELECT prd.id_producto,
		prd.clave,
		prd.modelo,
		prd.nombre,
		prd.precio_venta,
		pmy.precio AS precio_mayoreo,
		prd.imagen
	FROM cat_productos_servicios AS prd
	LEFT OUTER JOIN tbl_precios_mayoreo AS pmy
		ON pmy.id_producto = prd.id_producto
	WHERE prd.clave LIKE in_info
		OR prd.codigo LIKE in_info
		OR prd.codigo_proveedor LIKE in_info
		OR prd.modelo LIKE in_info
		OR prd.descripcion LIKE in_info
		OR prd.nombre LIKE in_info;
END$$

DELIMITER ;



DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_updateProducto`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_updateProducto`(
	in_id_producto INT,
	in_clave VARCHAR(20),
	in_codigo VARCHAR(20),
	in_codigo_proveedor VARCHAR(80),
	in_nombre VARCHAR(100),
	in_modelo VARCHAR(100),
	in_descripcion TEXT,
	in_precio_venta DECIMAL(15,2),
	in_tasa_iva DECIMAL(7,2),
	in_peso VARCHAR(15),
	in_longitud VARCHAR(15),
	in_superficie VARCHAR(15),
	in_volumen VARCHAR(15),
	in_id_unidad_medida INT,
	in_tipo_producto INT,
	in_iva_incluido INT,
	in_imagen TEXT
)
    COMMENT 'Inserta o actualiza un Producto'
BEGIN
	INSERT INTO cat_productos_servicios
	SET id_producto = in_id_producto,
		clave = in_clave,
		codigo = in_codigo,
		codigo_proveedor = in_codigo_proveedor,
		nombre = in_nombre,
		modelo = in_modelo,
		descripcion = in_descripcion,
		precio_venta = in_precio_venta,
		tasa_iva = in_tasa_iva,
		peso = in_peso,
		longitud = in_longitud,
		superficie = in_superficie,
		volumen = in_volumen,
		id_unidad_medida = in_id_unidad_medida,
		tipo_producto = in_tipo_producto,
		iva_incluido = in_iva_incluido,
		imagen = in_imagen
	ON DUPLICATE KEY
	UPDATE clave = in_clave,
		codigo = in_codigo,
		codigo_proveedor = in_codigo_proveedor,
		nombre = in_nombre,
		modelo = in_modelo,
		descripcion = in_descripcion,
		precio_venta = in_precio_venta,
		tasa_iva = in_tasa_iva,
		peso = in_peso,
		longitud = in_longitud,
		superficie = in_superficie,
		volumen = in_volumen,
		id_unidad_medida = in_id_unidad_medida,
		tipo_producto = in_tipo_producto,
		iva_incluido = in_iva_incluido,
		imagen = in_imagen;
END$$

DELIMITER ;